![pypi](https://img.shields.io/pypi/v/siterank.svg)
![python](https://img.shields.io/pypi/pyversions/siterank.svg)
![license](https://img.shields.io/github/license/prahladyeri/siterank.svg)
![docs](https://readthedocs.org/projects/siterank/badge/?version=latest)
[![patreon](https://img.shields.io/badge/Patreon-brown.svg?logo=patreon)](https://www.patreon.com/prahladyeri)
[![paypal](https://img.shields.io/badge/PayPal-blue.svg?logo=paypal)](https://paypal.me/prahladyeri)
[![follow](https://img.shields.io/twitter/follow/prahladyeri.svg?style=social)](https://twitter.com/prahladyeri)

# siterank
A python script to get alexa global rank for a given website or domain.

# Installation

	pip install siterank

# Usage

![screenshot](https://raw.githubusercontent.com/prahladyeri/siterank/master/screenshot.png)
